@@ -3,15 +3,12 @@ use 5.012005;
 use strict;
 use warnings;
 require Exporter;
+our $VERSION = '0.05';
 
 =head1 NAME
 
 Tsk - Perl bindings for Tsk (forensic analysis library). 
 
-=head1 VERSION
-
-Version 0.04
-
 =head1 DESCRIPTION
 
 Tsk is a module that provides Perl bindings for the sleuthkit toolkit.
@@ -20,9 +17,9 @@ It can be used for a variety of purposes:
 
 =over
 
-=item * filesystem crash recovery
+=item * filesystem data recovery
 
-=item * forensic analysis, investigations, incident response
+=item * forensic analysis, incident response
 
 =item * learning low-level filesystem (meta)data operations and data structures
 
@@ -43,33 +40,20 @@ If you want to install using cpanm, make sure you allow for big timeouts
 
 =head3 Ubuntu/Debian
 
-    aptitude install zlib1g-dev
-    aptitude install zlib1g
-    aptitude install libssl-dev
-    aptitude install gcc
-    aptitude install g++
-    aptitude install autoconf
-    aptitude install automake
-    aptitude install make
-    aptitude install libtool
-    aptitude install libfuse-dev
+    aptitude install gcc g++ automake autoconf make libtool libfuse-dev zlib1g-dev zlib1g libssl-dev
 
 =head3 Mageia
 
-    urpmi lib64fuse-devel
-    urpmi autoconf
-    urpmi automake
-    urpmi libtool
-    urpmi gcc gcc-c++
-    urpmi make
-    urpmi perl-devel
-    urpmi zlib
-    urpmi lib64zlib-devel
-    urpmi openssl-devel (or lib64openssl-devel)
+    urpmi lib64fuse-devel autoconf automake libtool gcc gcc-c++ make perl-devel zlib lib64zlib-devel openssl-devel lib64openssl-devel
 
-=head3 Gentoo
+=head3 OS X
 
-TODO
+    brew install pkg-config gcc g++ automake autoconf binutils osxfuse perl openssl libtool
+
+=head3 Windows
+
+Currently Tsk XS code compiles on Windows, however there are problems linking to
+libtsk.a (if sleuthkit is compiled using Cygwin or MSYS) or libtsk.lib(if it's compiled with MSVC).
 
 =head1 SAMPLES
 
@@ -85,7 +69,7 @@ Extracts the metadata files $Mft, $LogFile, $UsnJrnl from an NTFS file system.
 
 Opens a disk image and walks through the filesystem structure.
 
-=item * C</samples/reading-file-in-batches.pl>
+=item * C</samples/reading-file-contents-in-batches.pl>
 
 Opens a disk image nad reads a file in batches.
 
@@ -109,10 +93,6 @@ L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Tsk>
 
 L<https://github.com/wsdookadr/Tsk-XS/issues>
 
-=head1 PATCHES
-
-Patches welcome 24/7
-
 =head1 AUTHOR
 
 Stefan Petrea, C<< <stefan at garage-coding.com> >>
@@ -238,7 +218,6 @@ our $TSK_FS_BLOCK_FLAG_RES     = 0x0100;
 our $TSK_FS_BLOCK_FLAG_AONLY   = 0x0200;
 
 
-our $VERSION = '0.041';
 
 our @EXPORT = qw{
                  $TSK_VS_TYPE_DETECT 
